diff graal/GraalCompiler/src/com/sun/c1x/ir/LoadIndexed.java @ 2622:91d3952f7eb7

Framestate work : using stateAFter and reducting the number of nodes with framestates. Intermediate state (does not pass tests)
author Gilles Duboscq <gilles.duboscq@oracle.com>
date Tue, 10 May 2011 12:37:46 +0200
parents 092e628ddd5d
children 569228710be8
line wrap: on
line diff
--- a/graal/GraalCompiler/src/com/sun/c1x/ir/LoadIndexed.java	Tue May 10 11:55:12 2011 +0200
+++ b/graal/GraalCompiler/src/com/sun/c1x/ir/LoadIndexed.java	Tue May 10 12:37:46 2011 +0200
@@ -42,11 +42,11 @@
      * @param index the instruction producing the index
      * @param length the instruction producing the length
      * @param elementType the element type
      * @param stateBefore the state before executing this instruction
      * @param graph
      */
-    public LoadIndexed(Value array, Value index, Value length, CiKind elementType, FrameState stateBefore, Graph graph) {
-        super(elementType.stackKind(), array, index, length, elementType, stateBefore, INPUT_COUNT, SUCCESSOR_COUNT, graph);
+    public LoadIndexed(Value array, Value index, Value length, CiKind elementType, FrameState stateAfter, Graph graph) {
+        super(elementType.stackKind(), array, index, length, elementType, stateAfter, INPUT_COUNT, SUCCESSOR_COUNT, graph);
     }
 
     /**
@@ -42,11 +42,11 @@
      * @param length the instruction producing the length
      * @param elementType the element type
-     * @param stateBefore the state before executing this instruction
+     * @param stateAfter the after before executing this instruction
      * @param graph
      */